==> dynetx-0.2.4.tar.gz: dynetx-0.2.4/README.md <==
# DyNetx - Dynamic Network analysis library

[![Build Status](https://travis-ci.org/GiulioRossetti/dynetx.svg?branch=master)](https://travis-ci.org/GiulioRossetti/dynetx)
[![Coverage Status](https://coveralls.io/repos/github/GiulioRossetti/dynetx/badge.svg?branch=master)](https://coveralls.io/github/GiulioRossetti/dynetx?branch=master)
[![Documentation Status](https://readthedocs.org/projects/dynetx/badge/?version=latest)](http://dynetx.readthedocs.io/en/latest/?badge=latest)
[![pyversions](https://img.shields.io/pypi/pyversions/dynetx.svg)](https://badge.fury.io/py/dynetx)
[![PyPI version](https://badge.fury.io/py/dynetx.svg)](https://badge.fury.io/py/dynetx)
[![Updates](https://pyup.io/repos/github/GiulioRossetti/dynetx/shield.svg)](https://pyup.io/repos/github/GiulioRossetti/dynetx/)
[![PyPI download month](https://img.shields.io/pypi/dm/dynetx.svg?color=blue&style=plastic)](https://pypi.python.org/pypi/dynetx/)
[![DOI](https://zenodo.org/badge/98746676.svg)](https://zenodo.org/badge/latestdoi/98746676)

![DyNetx logo](http://dynetx.readthedocs.io/en/latest/_static/dynetx.png)


DyNetx provides implementations of dynamic networks in python (it is built upon [networkx](http://networkx.github.io)).

The project documentation can be found on [ReadTheDocs](http://dynetx.readthedocs.io).

## Citation

> Rossetti, G. (2020) DyNetx: dynamic network analysis library, v0.2.1, Zenodo, doi: 10.5281/zenodo.3953119


## Installation

In order to install the library just download (or clone) the current project and copy the dynetx folder in the root of your application.
Alternatively use pip:
```bash
sudo pip install dynetx
```

==> dynetx-0.2.6.tar.gz: dynetx-0.2.6/README.md <==
# DyNetx - Dynamic Network analysis library

[![Build Status](https://travis-ci.org/GiulioRossetti/dynetx.svg?branch=master)](https://travis-ci.org/GiulioRossetti/dynetx)
[![Coverage Status](https://coveralls.io/repos/github/GiulioRossetti/dynetx/badge.svg?branch=master)](https://coveralls.io/github/GiulioRossetti/dynetx?branch=master)
[![Documentation Status](https://readthedocs.org/projects/dynetx/badge/?version=latest)](http://dynetx.readthedocs.io/en/latest/?badge=latest)
[![pyversions](https://img.shields.io/pypi/pyversions/dynetx.svg)](https://badge.fury.io/py/dynetx)
[![PyPI version](https://badge.fury.io/py/dynetx.svg)](https://badge.fury.io/py/dynetx)
[![Updates](https://pyup.io/repos/github/GiulioRossetti/dynetx/shield.svg)](https://pyup.io/repos/github/GiulioRossetti/dynetx/)
[![Downloads](https://pepy.tech/badge/dynetx)](https://pepy.tech/project/dynetx)
[![Downloads](https://pepy.tech/badge/dynetx/month)](https://pepy.tech/project/dynetx)
[![DOI](https://zenodo.org/badge/98746676.svg)](https://zenodo.org/badge/latestdoi/98746676)
[![SBD++](https://img.shields.io/badge/Available%20on-SoBigData%2B%2B-green)](https://sobigdata.d4science.org/group/sobigdata-gateway/explore?siteId=20371853)

![DyNetx logo](http://dynetx.readthedocs.io/en/latest/_static/dynetx.png)


DyNetx provides implementations of dynamic networks in python (it is built upon [networkx](http://networkx.github.io)).

The project documentation can be found on [ReadTheDocs](http://dynetx.readthedocs.io).

If you would like to test ``DyNetx`` functionalities withouth installing anything on your machine consider using the preconfigured Jupyter Hub instances offered by [SoBigData++](https://sobigdata.d4science.org/group/sobigdata-gateway/explore?siteId=20371853).


## Citation

> Rossetti, G. (2020) DyNetx: dynamic network analysis library, v0.2.1, Zenodo, doi: 10.5281/zenodo.3953119


## Installation

In order to install the library just download (or clone) the current project and copy the dynetx folder in the root of your application.
Alternatively use pip:
```bash
sudo pip install dynetx
```
